@@ -31,8 +31,9 @@
 
 (define (count-prim-classes)
   (let ((i-count 0))
-    (for-each (lambda (lst) (if (eq? (cadr lst) bytevector?)
-				(set! i-count (+ i-count 1))))
+    (for-each (lambda (lst)
+		(if (eq? (cadr lst) bytevector?)
+		    (set! i-count (+ i-count 1))))
 	      gl-custom-prim-classes)
     i-count))
 
